// Class CLed, Version 1.0 July 2008

#include "afxwin.h"
#include "resource.h"
#include "Led.h"


CLed::CLed()
{
	m_LedBitmap.LoadBitmap(IDB_LEDS) ;

	m_nLedColor = LED_COLOR_RED ;
	m_nLedMode	= LED_OFF ;
	m_nLedShape = LED_ROUND ;
}


CLed::~CLed()
{
	VERIFY(m_LedBitmap.DeleteObject()) ;
}


BEGIN_MESSAGE_MAP(CLed, CStatic)
	//{{AFX_MSG_MAP(CLed)
	ON_WM_PAINT()
	ON_WM_CREATE()
	ON_WM_ERASEBKGND()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()


void CLed::OnPaint() 
{
	CPaintDC dc(this) ; // device context for painting
	DrawLed(&dc,m_nLedColor,m_nLedMode,m_nLedShape) ;
	
	// Do not call CStatic::OnPaint() for painting messages
}


void CLed::DrawLed(CDC *pDC,int nLEDColor, int nMode, int nShape)
{
	CRect rect ;
	GetClientRect(&rect) ;

	//
	// Center led within an oversized window
	//

	if( rect.Width() >= LED_SIZE && rect.Height() >= LED_SIZE ) {

		int nWidth	= rect.Width() ;
		int nHeight = rect.Height() ;
		
		rect.left	+= (nWidth - LED_SIZE)/2 ;
		rect.right	-= (nWidth - LED_SIZE)/2 ;
		rect.top	+= (nHeight - LED_SIZE)/2;
		rect.bottom -= (nHeight - LED_SIZE)/2;
	}

	CBitmap TransBitmap ;
	TransBitmap.CreateBitmap(LED_SIZE,LED_SIZE,1,1,NULL) ;
	CBitmap bitmapTemp ;
	CBitmap* pBitmap = &m_LedBitmap ;
	CDC srcDC ;
	CDC dcMask ;
	CDC TempDC ;
	TempDC.CreateCompatibleDC(pDC) ;
	srcDC.CreateCompatibleDC(pDC) ;
	dcMask.CreateCompatibleDC(pDC) ;

	CBitmap* pOldBitmap = srcDC.SelectObject(pBitmap) ;
	CBitmap* pOldMaskbitmap = dcMask.SelectObject(&TransBitmap) ;
	bitmapTemp.CreateCompatibleBitmap(pDC,LED_SIZE,LED_SIZE) ;

	CBitmap *pOldBitmapTemp = TempDC.SelectObject(&bitmapTemp) ;
	TempDC.BitBlt(0, 0, LED_SIZE, LED_SIZE, pDC, rect.left, rect.top, SRCCOPY) ; 

	COLORREF OldBkColor = srcDC.SetBkColor(RGB(255,0,255));
	dcMask.BitBlt(0, 0, LED_SIZE, LED_SIZE,&srcDC, nMode*LED_SIZE, nLEDColor+nShape, SRCCOPY) ; 
	TempDC.SetBkColor(OldBkColor) ;

	TempDC.BitBlt(0, 0, LED_SIZE, LED_SIZE, &srcDC, nMode*LED_SIZE, nLEDColor+nShape, SRCINVERT) ; 
	TempDC.BitBlt(0, 0, LED_SIZE, LED_SIZE,&dcMask, 0, 0, SRCAND); 
	TempDC.BitBlt(0, 0, LED_SIZE, LED_SIZE, &srcDC, nMode*LED_SIZE, nLEDColor+nShape, SRCINVERT) ; 

	pDC->BitBlt(rect.left, rect.top, LED_SIZE, LED_SIZE, &TempDC, 0, 0, SRCCOPY) ; 

	srcDC.SelectObject(pOldBitmap) ;
	dcMask.SelectObject(pOldMaskbitmap) ;
	TempDC.SelectObject(pOldBitmapTemp) ;
	VERIFY(srcDC.DeleteDC()) ;
	VERIFY(dcMask.DeleteDC()) ;
	VERIFY(TempDC.DeleteDC()) ;
	VERIFY(TransBitmap.DeleteObject()) ;
	VERIFY(bitmapTemp.DeleteObject()) ;
}


///////////////////////////////////////////////////////////////////////////////
// Name:		SetLed
// Description:	This method will draw and set led parameters.
//
// Entry:		int iLedColor - Where color is defined by:
//			 		LED_COLOR_RED
//					LED_COLOR_GREEN
//					LED_COLOR_YELLOW
//					LED_COLOR_BLUE
//
//				int iMode - where mode is defined by:
//					LED_ON
//					LED_OFF
//					LED_DISABLED
//
///////////////////////////////////////////////////////////////////////////////
void CLed::SetLed(int nLedColor, int nMode)
{
	m_nLedColor	= nLedColor ;
	m_nLedMode	= nMode ;
	m_nLedShape = LED_ROUND ;

	CDC *pDC ;
	pDC = GetDC() ;
	DrawLed(pDC,m_nLedColor,m_nLedMode,m_nLedShape) ;
	ReleaseDC(pDC) ;
}


BOOL CLed::OnEraseBkgnd(CDC* pDC) 
{
	// No background rendering
	return TRUE;
}

